@@ -84,16 +84,14 @@ func TestCollect(t *testing.T) {
 				DryRun: true,
 			},
 		},
-
-		// Error cases
-		"Missing consent file errors": {
+		"Missing consent file does not error in dry run": {
 			source: "missing_consent_file",
 			collectFlags: insights.CollectFlags{
 				DryRun: true,
 			},
-
-			wantErr: true,
 		},
+
+		// Error cases
 		"Invalid source metrics JSON errors": {
 			source: "valid_true",
 			collectFlags: insights.CollectFlags{
@@ -157,12 +155,148 @@ func TestCollect(t *testing.T) {
 			}
 
 			// test that dry run was applied.
-			f, err := os.Open(filepath.Join(dir, tc.source, "local"))
-			require.NoError(t, err, "Setup: failed to open temp directory")
-			defer f.Close()
+			assert.NoDirExists(t, filepath.Join(dir, tc.source, "local"))
+			assert.NoDirExists(t, filepath.Join(dir, tc.source, "uploaded"))
+		})
+	}
+}
 
-			_, err = f.Readdir(1)
-			assert.ErrorIs(t, err, io.EOF)
+func TestCompile(t *testing.T) {
+	t.Parallel()
+
+	tests := map[string]struct {
+		compileFlags insights.CompileFlags
+
+		wantErr bool
+	}{
+		"Without source metrics": {},
+		"With valid JSON source metrics": {
+			compileFlags: insights.CompileFlags{
+				SourceMetricsJSON: []byte(`{"key": "source metrics JSON"}`),
+			},
+		},
+		"With valid source metrics path": {
+			compileFlags: insights.CompileFlags{
+				SourceMetricsPath: "custom.json",
+			},
+		},
+
+		// Error cases
+		"Errors with both SourceMetricsJSON and SourceMetricsPath": {
+			compileFlags: insights.CompileFlags{
+				SourceMetricsJSON: []byte(`{"key": "source metrics JSON"}`),
+				SourceMetricsPath: "custom.json",
+			},
+			wantErr: true,
+		},
+		"Errors with invalid JSON source metrics": {
+			compileFlags: insights.CompileFlags{
+				SourceMetricsJSON: []byte(`{"key": "invalid metrics JSON"`),
+			},
+			wantErr: true,
+		},
+		"Errors with non-object source metrics JSON": {
+			compileFlags: insights.CompileFlags{
+				SourceMetricsJSON: []byte(`["array", "not", "object"]`),
+			},
+			wantErr: true,
+		},
+		"Errors with invalid source metrics path": {
+			compileFlags: insights.CompileFlags{
+				SourceMetricsPath: "invalid.json",
+			},
+			wantErr: true,
+		},
+	}
+	for name, tc := range tests {
+		t.Run(name, func(t *testing.T) {
+			t.Parallel()
+
+			if tc.compileFlags.SourceMetricsPath != "" {
+				tc.compileFlags.SourceMetricsPath = filepath.Join("testdata", "metrics", tc.compileFlags.SourceMetricsPath)
+			}
+
+			// Compile doesn't use anything but the logger.
+			report, err := insights.Config{}.Compile(tc.compileFlags)
+
+			if tc.wantErr {
+				require.Error(t, err)
+				return
+			}
+			require.NoError(t, err)
+
+			// Check the returned report
+			mReport := collector.Insights{}
+			err = json.Unmarshal(report, &mReport)
+			require.NoError(t, err, "Failed to unmarshal report")
+			assert.NotEmpty(t, mReport.InsightsVersion, "Insights version should not be empty")
+
+			if tc.compileFlags.SourceMetricsJSON != nil || tc.compileFlags.SourceMetricsPath != "" {
+				assert.NotEmpty(t, mReport.SourceMetrics, "Source metrics should not be empty")
+			} else {
+				assert.Empty(t, mReport.SourceMetrics, "Source metrics should be empty when not provided")
+			}
+		})
+	}
+}
+
+func TestWrite(t *testing.T) {
+	t.Parallel()
+
+	tests := map[string]struct {
+		source string
+		report []byte
+
+		wantErr bool
+	}{
+		"Valid source and empty insights doesn't error": {
+			source: "valid_true",
+			report: []byte(`{}`),
+		},
+		"Valid source and insights doesn't error": {
+			source: "valid_true",
+			report: []byte(`{"insightsVersion": "1.0.0", "sourceMetrics": {"inner": "value"}}`),
+		},
+
+		// Error cases
+		"Invalid source errors": {
+			source:  "invalid",
+			report:  []byte(`{}`),
+			wantErr: true,
+		},
+		"Nil insights errors": {
+			source:  "valid_true",
+			report:  nil,
+			wantErr: true,
+		},
+		"Unexpect insights fields errors": {
+			source:  "valid_true",
+			report:  []byte(`{"insightsVersion": "1.0.0", "sourceMetrics": {"inner": "value"}, "unexpectedField": "value"}`),
+			wantErr: true,
+		},
+	}
+
+	for name, tc := range tests {
+		t.Run(name, func(t *testing.T) {
+			t.Parallel()
+
+			dir := t.TempDir()
+
+			conf := insights.Config{
+				ConsentDir:  filepath.Join("testdata", "consent_files"),
+				InsightsDir: dir,
+			}
+
+			err := conf.Write(tc.source, tc.report, insights.WriteFlags{DryRun: true})
+			if tc.wantErr {
+				require.Error(t, err, "Expected error from write but got none")
+				return
+			}
+			require.NoError(t, err, "Got unexpected error from write")
+
+			// test that dry run was applied.
+			assert.NoDirExists(t, filepath.Join(dir, tc.source, "local"))
+			assert.NoDirExists(t, filepath.Join(dir, tc.source, "uploaded"))
 		})
 	}
 }
