@@ -35,16 +35,6 @@ type Insights struct {
 	SourceMetrics   map[string]any `json:"sourceMetrics,omitempty"`
 }
 
-type timeProvider interface {
-	Now() time.Time
-}
-
-type realTimeProvider struct{}
-
-func (realTimeProvider) Now() time.Time {
-	return time.Now()
-}
-
 // Consent is an interface for getting the consent state for a given source.
 type Consent interface {
 	HasConsent(source string) (bool, error)
@@ -58,18 +48,21 @@ type SysInfo interface {
 // Collector is an interface for the collector component.
 type Collector interface {
 	// Compile checks if appropriate to make a new report, and if so, collects and compiles the data into a report.
-	// If force is true, it ignores duplicate checks.
-	Compile(force bool) (Insights, error)
+	Compile() (Insights, error)
 
 	// Write writes the insights report to disk, and cleans up old reports.
-	// If dryRun is true, it does not actually write the report.
-	Write(insights Insights, dryRun bool) error
+	//
+	// If force is true, then Write will overwrite any existing reports for a given period.
+	// If dryRun is true, then Write does nothing, other than checking consent.
+	//
+	// Note that duplicity checks and the timestamp in the file name is based on the current time,
+	// not the collection time of the Insights report passed.
+	Write(insights Insights, period uint32, force, dryRun bool) error
 }
 
 // collector is an abstraction of the collector component.
 type collector struct {
 	consent Consent
-	period  uint32
 	source  string
 
 	collectedDir      string
@@ -79,7 +72,7 @@ type collector struct {
 
 	// Overrides for testing.
 	maxReports uint32
-	time       time.Time
+	time       int64
 	sysInfo    SysInfo
 
 	log *slog.Logger
@@ -87,14 +80,16 @@ type collector struct {
 
 type options struct {
 	// Private members exported for tests.
-	maxReports   uint32
-	timeProvider timeProvider
-	sysInfo      func(*slog.Logger, ...sysinfo.Options) SysInfo
+	maxReports uint32
+	time       timeFunc
+	sysInfo    func(*slog.Logger, ...sysinfo.Options) SysInfo
 }
 
+type timeFunc func() int64
+
 var defaultOptions = options{
-	maxReports:   constants.MaxReports,
-	timeProvider: realTimeProvider{},
+	maxReports: constants.MaxReports,
+	time:       func() int64 { return time.Now().Unix() },
 	sysInfo: func(l *slog.Logger, opts ...sysinfo.Options) SysInfo {
 		return sysinfo.New(l, opts...)
 	},
@@ -106,7 +101,6 @@ type Options func(*options)
 // Config represents the collector specific data needed to collect.
 type Config struct {
 	Source            string
-	Period            uint32
 	CachePath         string
 	SourceMetricsPath string
 	SourceMetricsJSON []byte
@@ -114,18 +108,12 @@ type Config struct {
 
 // Sanitize sets defaults and checks that the Config is properly configured.
 func (c *Config) Sanitize(l *slog.Logger) error {
-	// Handle global source and source metrics.
+	// Handle default source and source metrics.
 	if c.Source == "" { // Default source to platform
 		c.Source = constants.DefaultCollectSource
 		l.Info("No source provided, defaulting to platform", "source", c.Source)
 	}
 
-	if c.Source == constants.DefaultCollectSource && (c.SourceMetricsPath != "" || c.SourceMetricsJSON != nil) {
-		l.Warn("Ignoring source metrics as they are not applicable for the platform source")
-		c.SourceMetricsPath = ""
-		c.SourceMetricsJSON = nil
-	}
-
 	if c.SourceMetricsPath != "" && c.SourceMetricsJSON != nil {
 		return errors.New("only one of SourceMetricsPath or SourceMetricsJSON can be provided")
 	}
@@ -147,7 +135,7 @@ func (c *Config) Sanitize(l *slog.Logger) error {
 // The internal time used for collecting and writing reports is the current time at the moment of creation of the Collector.
 // Sanitize the config before use, but Sanitize may be called beforehand safely.
 func New(l *slog.Logger, cm Consent, c Config, args ...Options) (Collector, error) {
-	l.Debug("Creating new collector", "source", c.Source, "period", c.Period)
+	l.Debug("Creating new collector", "source", c.Source)
 
 	if cm == nil {
 		return collector{}, fmt.Errorf("consent manager cannot be nil")
@@ -168,10 +156,9 @@ func New(l *slog.Logger, cm Consent, c Config, args ...Options) (Collector, erro
 
 	return collector{
 		consent: cm,
-		period:  c.Period,
 		source:  c.Source,
 
-		time:              opts.timeProvider.Now(),
+		time:              opts.time(),
 		collectedDir:      filepath.Join(c.CachePath, c.Source, constants.LocalFolder),
 		uploadedDir:       filepath.Join(c.CachePath, c.Source, constants.UploadedFolder),
 		sourceMetricsPath: c.SourceMetricsPath,
@@ -183,29 +170,14 @@ func New(l *slog.Logger, cm Consent, c Config, args ...Options) (Collector, erro
 	}, nil
 }
 
-// Compile checks if appropriate to make a new report, and if so, collects and compiles the data into a report.
+// Compile collects and compiles data into a report.
 //
-// Checks if a report already exists for the current period, and returns an error if it does.
-// Does not check consent, as this should be done at write time.
+// Compile does not check consent or report duplicity, as this should be done at write time.
 // Note that any source metrics must be a valid JSON object, not an array or primitive.
-func (c collector) Compile(force bool) (insights Insights, err error) {
-	c.log.Debug("Collecting data", "force", force)
+func (c collector) Compile() (insights Insights, err error) {
+	c.log.Debug("Collecting data")
 	defer decorate.OnError(&err, "insights compile failed")
 
-	if err := c.makeDirs(); err != nil {
-		return Insights{}, err
-	}
-
-	if !force {
-		duplicate, err := c.duplicateExists()
-		if err != nil {
-			return Insights{}, err
-		}
-		if duplicate {
-			return Insights{}, ErrDuplicateReport
-		}
-	}
-
 	insights, err = c.compile()
 	if err != nil {
 		return Insights{}, fmt.Errorf("failed to compile insights: %w", err) // Need to expose these errors
@@ -216,11 +188,14 @@ func (c collector) Compile(force bool) (insights Insights, err error) {
 }
 
 // Write writes the insights report to disk, and cleans up old reports.
-// Does not check for duplicates, as this should be done in Compile.
 //
-// If the dryRun is true, then Write does nothing, other than checking consent.
-func (c collector) Write(insights Insights, dryRun bool) (err error) {
-	c.log.Debug("Writing data", "dryRun", dryRun)
+// If force is true, then Write will overwrite any existing reports for a given period.
+// If dryRun is true, then Write does nothing, other than checking consent.
+//
+// Note that duplicity checks and the timestamp in the file name is based on the current time,
+// not the collection time of the Insights report passed.
+func (c collector) Write(insights Insights, period uint32, force, dryRun bool) (err error) {
+	c.log.Debug("Writing data", "period", period, "force", force, "dryRun", dryRun)
 	defer decorate.OnError(&err, "insights write failed")
 
 	data, err := json.Marshal(insights)
@@ -235,10 +210,19 @@ func (c collector) Write(insights Insights, dryRun bool) (err error) {
 	if consent {
 		c.log.Info("Consent granted, writing insights report")
 	} else {
-		c.log.Warn("Insights data will not be written to disk, as consent was not provided.")
+		c.log.Info("Consent not granted, writing optout instead of insights report")
 		data = constants.OptOutPayload
 	}
 
+	time := insights.CollectionTime
+	if time == 0 {
+		time = c.time // If no collection time is provided (zero value), use the current time
+	}
+
+	if err := c.handleDuplicates(force, dryRun, time, period); err != nil {
+		return err
+	}
+
 	if dryRun {
 		c.log.Info("Dry run, not writing insights report")
 		return nil
@@ -248,7 +232,7 @@ func (c collector) Write(insights Insights, dryRun bool) (err error) {
 		return fmt.Errorf("failed to create directories: %v", err)
 	}
 
-	if err := c.write(data); err != nil {
+	if err := c.write(data, time); err != nil {
 		return fmt.Errorf("failed to write insights report: %v", err)
 	}
 
@@ -269,15 +253,54 @@ func (c collector) makeDirs() error {
 	return nil
 }
 
+// handleDuplicates checks and handles duplicates based on the force flag.
+// If force is false and there are duplicates in either the collected or uploaded directories, it will error.
+// Otherwise, if force is true, it will clear out all existing reports for the given period in the collected dir.
+func (c collector) handleDuplicates(force, dryRun bool, time int64, period uint32) error {
+	if !force {
+		duplicate, err := c.duplicateExists(time, period)
+		if err != nil {
+			return err
+		}
+		if duplicate {
+			return ErrDuplicateReport
+		}
+	}
+
+	// If force is true, clear out all existing reports for the given period.
+	if force {
+		if _, err := os.Stat(c.collectedDir); err != nil {
+			if os.IsNotExist(err) {
+				return nil
+			}
+			return err
+		}
+
+		if err := report.ClearPeriod(c.log, c.collectedDir, time, period, dryRun); err != nil {
+			return fmt.Errorf("failed to clear old reports: %v", err)
+		}
+	}
+
+	return nil
+}
+
 // duplicateExists returns true if a report for the current period already exists in the uploaded or collected directories.
-func (c collector) duplicateExists() (bool, error) {
-	for _, dir := range []string{c.collectedDir, c.uploadedDir} {
-		cReport, err := report.GetForPeriod(c.log, dir, c.time, c.period)
+// Directories are only checked if they exist.
+func (c collector) duplicateExists(time int64, period uint32) (bool, error) {
+	dirs := []string{}
+	if _, err := os.Stat(c.collectedDir); !os.IsNotExist(err) {
+		dirs = append(dirs, c.collectedDir)
+	}
+	if _, err := os.Stat(c.uploadedDir); !os.IsNotExist(err) {
+		dirs = append(dirs, c.uploadedDir)
+	}
+
+	for _, dir := range dirs {
+		duplicateExists, err := report.DuplicateExists(c.log, dir, time, period)
 		if err != nil {
 			return false, fmt.Errorf("failed to check for duplicate report in %s for period: %v", dir, err)
 		}
-		if cReport.Name != "" {
-			c.log.Info("Duplicate report already exists", "file", cReport.Path)
+		if duplicateExists {
 			return true, nil
 		}
 	}
@@ -289,7 +312,7 @@ func (c collector) duplicateExists() (bool, error) {
 func (c collector) compile() (Insights, error) {
 	insights := Insights{
 		InsightsVersion: constants.Version,
-		CollectionTime:  c.time.Unix(),
+		CollectionTime:  c.time,
 	}
 
 	// Collect system information.
@@ -347,9 +370,7 @@ func (c collector) getSourceMetrics() (map[string]any, error) {
 }
 
 // write writes the insights report to disk, with the appropriate name.
-func (c collector) write(insights []byte) error {
-	time := report.GetPeriodStart(c.period, c.time)
-
+func (c collector) write(insights []byte, time int64) error {
 	reportPath := filepath.Join(c.collectedDir, fmt.Sprintf("%v.json", time))
 	if err := fileutils.AtomicWrite(reportPath, insights); err != nil {
 		return fmt.Errorf("failed to write to disk: %v", err)
